[libpng15] Imported from libpng-1.5.15beta06.tar
diff --git a/LICENSE b/LICENSE
index 871031c..ab824ca 100644
--- a/LICENSE
+++ b/LICENSE
@@ -10,7 +10,7 @@
 
 This code is released under the libpng license.
 
-libpng versions 1.2.6, August 15, 2004, through 1.5.15beta06, February 18, 2013, are
+libpng versions 1.2.6, August 15, 2004, through 1.5.15beta06, February 22, 2013, are
 Copyright (c) 2004, 2006-2012 Glenn Randers-Pehrson, and are
 distributed according to the same disclaimer and license as libpng-1.2.5
 with the following individual added to the list of Contributing Authors
@@ -108,4 +108,4 @@
 
 Glenn Randers-Pehrson
 glennrp at users.sourceforge.net
-February 18, 2013
+February 22, 2013
diff --git a/README b/README
index 6b1c5d9..5d9a229 100644
--- a/README
+++ b/README
@@ -1,4 +1,4 @@
-README for libpng version 1.5.15beta06 - February 18, 2013 (shared library 15.0)
+README for libpng version 1.5.15beta06 - February 22, 2013 (shared library 15.0)
 See the note about version numbers near the top of png.h
 
 See INSTALL for instructions on how to install libpng.
diff --git a/config.h.in b/config.h.in
index bce6c11..8905c19 100644
--- a/config.h.in
+++ b/config.h.in
@@ -79,6 +79,9 @@
 /* ARM NEON filter initialization function */
 #undef PNG_FILTER_OPTIMIZATIONS
 
+/* Turn off run-time checking for ARM NEON support */
+#undef PNG_NO_ARM_NEON_CHECK
+
 /* Define to 1 if you have the ANSI C header files. */
 #undef STDC_HEADERS
 
diff --git a/configure b/configure
index 1d0f4c5..3c7d78c 100755
--- a/configure
+++ b/configure
@@ -1435,7 +1435,8 @@
   --enable-fast-install[=PKGS]
                           optimize for fast installation [default=yes]
   --disable-libtool-lock  avoid locking (might break parallel builds)
-  --enable-arm-neon       Enable ARM NEON optimizations
+  --enable-arm-neon     Enable ARM NEON optimizations: use 'always' to turn
+                          off run-time checks
 
 Optional Packages:
   --with-PACKAGE[=ARG]    use PACKAGE [ARG=yes]
@@ -12811,17 +12812,22 @@
 
 # Check whether --enable-arm-neon was given.
 if test "${enable_arm_neon+set}" = set; then :
-  enableval=$enable_arm_neon; if test "${enableval}" = yes; then
+  enableval=$enable_arm_neon; if test "${enableval}" = "yes" -o "${enableval}" = "always"; then
 
 $as_echo "#define PNG_FILTER_OPTIMIZATIONS png_init_filter_functions_neon" >>confdefs.h
 
 
 $as_echo "#define PNG_ALIGNED_MEMORY_SUPPORTED 1" >>confdefs.h
 
-	fi
+      if test "${enableval}" = "always"; then
+
+$as_echo "#define PNG_NO_ARM_NEON_CHECK /**/" >>confdefs.h
+
+      fi
+    fi
 fi
 
- if test "${enable_arm_neon:-no}" = yes; then
+ if test "${enable_arm_neon:-no}" != "no"; then
   PNG_ARM_NEON_TRUE=
   PNG_ARM_NEON_FALSE='#'
 else
@@ -12830,6 +12836,9 @@
 fi
 
 
+ { $as_echo "$as_me:${as_lineno-$LINENO}: Extra options for compiler: $PNG_COPTS" >&5
+$as_echo "$as_me: Extra options for compiler: $PNG_COPTS" >&6;}
+
 # Config files, substituting as above
 ac_config_files="$ac_config_files Makefile libpng.pc:libpng.pc.in"
 
diff --git a/libpng-manual.txt b/libpng-manual.txt
index 0f549a5..ac7705d 100644
--- a/libpng-manual.txt
+++ b/libpng-manual.txt
@@ -1,6 +1,6 @@
 Libpng-manual.txt - A description on how to use and modify libpng
 
- libpng version 1.5.15beta06 - February 18, 2013
+ libpng version 1.5.15beta06 - February 22, 2013
  Updated and distributed by Glenn Randers-Pehrson
  <glennrp at users.sourceforge.net>
  Copyright (c) 1998-2013 Glenn Randers-Pehrson
@@ -11,7 +11,7 @@
 
  Based on:
 
- libpng versions 0.97, January 1998, through 1.5.15beta06 - February 18, 2013
+ libpng versions 0.97, January 1998, through 1.5.15beta06 - February 22, 2013
  Updated and distributed by Glenn Randers-Pehrson
  Copyright (c) 1998-2013 Glenn Randers-Pehrson
 
@@ -4622,7 +4622,7 @@
 
 XIV. Y2K Compliance in libpng
 
-February 18, 2013
+February 22, 2013
 
 Since the PNG Development group is an ad-hoc body, we can't make
 an official declaration.
diff --git a/libpng.3 b/libpng.3
index 197c3e0..12d80f5 100644
--- a/libpng.3
+++ b/libpng.3
@@ -1,4 +1,4 @@
-.TH LIBPNG 3 "February 18, 2013"
+.TH LIBPNG 3 "February 22, 2013"
 .SH NAME
 libpng \- Portable Network Graphics (PNG) Reference Library 1.5.15beta06
 .SH SYNOPSIS
@@ -492,7 +492,7 @@
 .SH LIBPNG.TXT
 Libpng-manual.txt - A description on how to use and modify libpng
 
- libpng version 1.5.15beta06 - February 18, 2013
+ libpng version 1.5.15beta06 - February 22, 2013
  Updated and distributed by Glenn Randers-Pehrson
  <glennrp at users.sourceforge.net>
  Copyright (c) 1998-2013 Glenn Randers-Pehrson
@@ -503,7 +503,7 @@
 
  Based on:
 
- libpng versions 0.97, January 1998, through 1.5.15beta06 - February 18, 2013
+ libpng versions 0.97, January 1998, through 1.5.15beta06 - February 22, 2013
  Updated and distributed by Glenn Randers-Pehrson
  Copyright (c) 1998-2013 Glenn Randers-Pehrson
 
@@ -5115,7 +5115,7 @@
 
 .SH XIV. Y2K Compliance in libpng
 
-February 18, 2013
+February 22, 2013
 
 Since the PNG Development group is an ad-hoc body, we can't make
 an official declaration.
@@ -5401,7 +5401,7 @@
 
 Thanks to Frank J. T. Wojcik for helping with the documentation.
 
-Libpng version 1.5.15beta06 - February 18, 2013:
+Libpng version 1.5.15beta06 - February 22, 2013:
 Initially created in 1995 by Guy Eric Schalnat, then of Group 42, Inc.
 Currently maintained by Glenn Randers-Pehrson (glennrp at users.sourceforge.net).
 
@@ -5424,7 +5424,7 @@
 
 This code is released under the libpng license.
 
-libpng versions 1.2.6, August 15, 2004, through 1.5.15beta06, February 18, 2013, are
+libpng versions 1.2.6, August 15, 2004, through 1.5.15beta06, February 22, 2013, are
 Copyright (c) 2004,2006-2007 Glenn Randers-Pehrson, and are
 distributed according to the same disclaimer and license as libpng-1.2.5
 with the following individual added to the list of Contributing Authors
@@ -5523,7 +5523,7 @@
 
 Glenn Randers-Pehrson
 glennrp at users.sourceforge.net
-February 18, 2013
+February 22, 2013
 
 .\" end of man page
 
diff --git a/libpngpf.3 b/libpngpf.3
index 215c727..b8ae147 100644
--- a/libpngpf.3
+++ b/libpngpf.3
@@ -1,4 +1,4 @@
-.TH LIBPNGPF 3 "February 18, 2013"
+.TH LIBPNGPF 3 "February 22, 2013"
 .SH NAME
 libpng \- Portable Network Graphics (PNG) Reference Library 1.5.15beta06
 (private functions)
diff --git a/png.5 b/png.5
index 9185085..a644a15 100644
--- a/png.5
+++ b/png.5
@@ -1,4 +1,4 @@
-.TH PNG 5 "February 18, 2013"
+.TH PNG 5 "February 22, 2013"
 .SH NAME
 png \- Portable Network Graphics (PNG) format
 .SH DESCRIPTION
diff --git a/png.c b/png.c
index b89c512..8b9424d 100644
--- a/png.c
+++ b/png.c
@@ -658,13 +658,13 @@
 #else
 #  ifdef __STDC__
    return PNG_STRING_NEWLINE \
-     "libpng version 1.5.15beta06 - February 18, 2013" PNG_STRING_NEWLINE \
+     "libpng version 1.5.15beta06 - February 22, 2013" PNG_STRING_NEWLINE \
      "Copyright (c) 1998-2013 Glenn Randers-Pehrson" PNG_STRING_NEWLINE \
      "Copyright (c) 1996-1997 Andreas Dilger" PNG_STRING_NEWLINE \
      "Copyright (c) 1995-1996 Guy Eric Schalnat, Group 42, Inc." \
      PNG_STRING_NEWLINE;
 #  else
-      return "libpng version 1.5.15beta06 - February 18, 2013\
+      return "libpng version 1.5.15beta06 - February 22, 2013\
       Copyright (c) 1998-2013 Glenn Randers-Pehrson\
       Copyright (c) 1996-1997 Andreas Dilger\
       Copyright (c) 1995-1996 Guy Eric Schalnat, Group 42, Inc.";
diff --git a/pngconf.h b/pngconf.h
index 5313eb6..78321ca 100644
--- a/pngconf.h
+++ b/pngconf.h
@@ -1,7 +1,7 @@
 
 /* pngconf.h - machine configurable file for libpng
  *
- * libpng version 1.5.15beta06 - February 18, 2013
+ * libpng version 1.5.15beta06 - February 22, 2013
  *
  * Copyright (c) 1998-2013 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
diff --git a/pngwrite.c b/pngwrite.c
index 18f535c..402e4fc 100644
--- a/pngwrite.c
+++ b/pngwrite.c
@@ -1,7 +1,7 @@
 
 /* pngwrite.c - general routines to write a PNG file
  *
- * Last changed in libpng 1.5.14 [January 24, 2013]
+ * Last changed in libpng 1.5.15 [(PENDING RELEASE)]
  * Copyright (c) 1998-2013 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
  * (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
@@ -456,7 +456,9 @@
 }
 
 /* Alternate initialize png_ptr structure, and allocate any memory needed */
+#ifdef PNG_WRITE_WEIGHTED_FILTER_SUPPORTED
 static void png_reset_filter_heuristics(png_structp png_ptr); /* forward decl */
+#endif
 
 PNG_FUNCTION(png_structp,PNGAPI
 png_create_write_struct_2,(png_const_charp user_png_ver, png_voidp error_ptr,
diff --git a/projects/vstudio/readme.txt b/projects/vstudio/readme.txt
index 2f348cc..a99ab37 100644
--- a/projects/vstudio/readme.txt
+++ b/projects/vstudio/readme.txt
@@ -1,7 +1,7 @@
 
 VisualStudio instructions
 
-libpng version 1.5.15beta06 - February 18, 2013
+libpng version 1.5.15beta06 - February 22, 2013
 
 Copyright (c) 1998-2010 Glenn Randers-Pehrson
 
diff --git a/projects/vstudio/zlib.props b/projects/vstudio/zlib.props
index 6687467..a048f2e 100644
--- a/projects/vstudio/zlib.props
+++ b/projects/vstudio/zlib.props
@@ -2,7 +2,7 @@
 <!--
  * zlib.props - location of zlib source
  *
- * libpng version 1.5.15beta06 - February 18, 2013
+ * libpng version 1.5.15beta06 - February 22, 2013
  *
  * Copyright (c) 1998-2011 Glenn Randers-Pehrson
  *
diff --git a/scripts/README.txt b/scripts/README.txt
index 8a03fd7..914f6ad 100644
--- a/scripts/README.txt
+++ b/scripts/README.txt
@@ -1,5 +1,5 @@
 
-Makefiles for  libpng version 1.5.15beta06 - February 18, 2013
+Makefiles for  libpng version 1.5.15beta06 - February 22, 2013
 
 pnglibconf.h.prebuilt       =>  Stores configuration settings
  makefile.linux    =>  Linux/ELF makefile
diff --git a/scripts/pnglibconf.h.prebuilt b/scripts/pnglibconf.h.prebuilt
index 24ba0b7..800143f 100644
--- a/scripts/pnglibconf.h.prebuilt
+++ b/scripts/pnglibconf.h.prebuilt
@@ -3,7 +3,7 @@
 
 /* pnglibconf.h - library build configuration */
 
-/* Libpng 1.5.15beta06 - February 19, 2013 */
+/* Libpng 1.5.15beta06 - February 22, 2013 */
 
 /* Copyright (c) 1998-2012 Glenn Randers-Pehrson */
diff --git a/png.h b/png.h
index e67ce83..38e4321 100644
--- a/png.h
+++ b/png.h
@@ -1,7 +1,7 @@
 
 /* png.h - header file for PNG reference library
  *
  * libpng version 1.5.15beta06 - February 18, 2013
  * Copyright (c) 1998-2013 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
  * (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
@@ -11,7 +11,7 @@
  * Authors and maintainers:
  *   libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
  *   libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
  *   libpng versions 0.97, January 1998, through 1.5.15beta06 - February 18, 2013: Glenn
  *   See also "Contributing Authors", below.
  *
  * Note about libpng version numbers:
@@ -216,7 +216,7 @@
  *
  * This code is released under the libpng license.
  *
  * libpng versions 1.2.6, August 15, 2004, through 1.5.15beta06, February 18, 2013, are
  * Copyright (c) 2004, 2006-2013 Glenn Randers-Pehrson, and are
  * distributed according to the same disclaimer and license as libpng-1.2.5
  * with the following individual added to the list of Contributing Authors:
@@ -328,7 +328,7 @@
  * Y2K compliance in libpng:
  * =========================
  *
- *    February 18, 2013
+ *    February 22, 2013
  *
  *    Since the PNG Development group is an ad-hoc body, we can't make
  *    an official declaration.
@@ -395,7 +395,7 @@
 /* Version information for png.h - this should match the version in png.c */
 #define PNG_LIBPNG_VER_STRING "1.5.15beta06"
 #define PNG_HEADER_VERSION_STRING \
-     " libpng version 1.5.15beta06 - February 18, 2013\n"
+     " libpng version 1.5.15beta06 - February 22, 2013\n"
 
 #define PNG_LIBPNG_VER_SONUM   15
 #define PNG_LIBPNG_VER_DLLNUM  15
@@ -1,7 +1,7 @@
 /* png.h - header file for PNG reference library
  *
- * libpng version 1.5.15beta06 - February 18, 2013
+ * libpng version 1.5.15beta06 - February 22, 2013
  * Copyright (c) 1998-2013 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
@@ -11,7 +11,7 @@
  *   libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
  *   libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
- *   libpng versions 0.97, January 1998, through 1.5.15beta06 - February 18, 2013: Glenn
+ *   libpng versions 0.97, January 1998, through 1.5.15beta06 - February 22, 2013: Glenn
  *   See also "Contributing Authors", below.
  *
@@ -216,7 +216,7 @@
  * This code is released under the libpng license.
  *
- * libpng versions 1.2.6, August 15, 2004, through 1.5.15beta06, February 18, 2013, are
+ * libpng versions 1.2.6, August 15, 2004, through 1.5.15beta06, February 22, 2013, are
  * Copyright (c) 2004, 2006-2013 Glenn Randers-Pehrson, and are
  * distributed according to the same disclaimer and license as libpng-1.2.5